vfbLib.parsers.base.OpenTypeMetricsClassFlagsParser
===================================================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: OpenTypeMetricsClassFlagsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OpenTypeMetricsClassFlagsParser.__init__
      ~OpenTypeMetricsClassFlagsParser.parse
      ~OpenTypeMetricsClassFlagsParser.parse_hex
      ~OpenTypeMetricsClassFlagsParser.read_double
      ~OpenTypeMetricsClassFlagsParser.read_doubles
      ~OpenTypeMetricsClassFlagsParser.read_float
      ~OpenTypeMetricsClassFlagsParser.read_floats
      ~OpenTypeMetricsClassFlagsParser.read_int16
      ~OpenTypeMetricsClassFlagsParser.read_int32
      ~OpenTypeMetricsClassFlagsParser.read_int8
      ~OpenTypeMetricsClassFlagsParser.read_str
      ~OpenTypeMetricsClassFlagsParser.read_str_all
      ~OpenTypeMetricsClassFlagsParser.read_uint16
      ~OpenTypeMetricsClassFlagsParser.read_uint32
      ~OpenTypeMetricsClassFlagsParser.read_uint8
      ~OpenTypeMetricsClassFlagsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OpenTypeMetricsClassFlagsParser.encoding
      ~OpenTypeMetricsClassFlagsParser.master_count
      ~OpenTypeMetricsClassFlagsParser.stream
      ~OpenTypeMetricsClassFlagsParser.ttStemsH_count
      ~OpenTypeMetricsClassFlagsParser.ttStemsV_count
   
   